==> zio-aws-ses_2.12-5.17.174.1-sources.jar: zio/aws/ses/model/DescribeReceiptRuleSetResponse.scala <==
package zio.aws.ses.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeReceiptRuleSetResponse(
    metadata: Optional[zio.aws.ses.model.ReceiptRuleSetMetadata] =
      Optional.Absent,
    rules: Optional[Iterable[zio.aws.ses.model.ReceiptRule]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse = {
    import DescribeReceiptRuleSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
      .builder()
      .optionallyWith(metadata.map(value => value.buildAwsValue()))(_.metadata)
      .optionallyWith(
        rules.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.rules)
      .build()
  }
  def asReadOnly: zio.aws.ses.model.DescribeReceiptRuleSetResponse.ReadOnly =
    zio.aws.ses.model.DescribeReceiptRuleSetResponse.wrap(buildAwsValue())
}
object DescribeReceiptRuleSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ses.model.DescribeReceiptRuleSetResponse =
      zio.aws.ses.model.DescribeReceiptRuleSetResponse(
        metadata.map(value => value.asEditable),
        rules.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def metadata: Optional[zio.aws.ses.model.ReceiptRuleSetMetadata.ReadOnly]
    def rules: Optional[List[zio.aws.ses.model.ReceiptRule.ReadOnly]]
    def getMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.ses.model.ReceiptRuleSetMetadata.ReadOnly
    ] = AwsError.unwrapOptionField("metadata", metadata)
    def getRules
        : ZIO[Any, AwsError, List[zio.aws.ses.model.ReceiptRule.ReadOnly]] =
      AwsError.unwrapOptionField("rules", rules)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
  ) extends zio.aws.ses.model.DescribeReceiptRuleSetResponse.ReadOnly {
    override val metadata
        : Optional[zio.aws.ses.model.ReceiptRuleSetMetadata.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metadata())
        .map(value => zio.aws.ses.model.ReceiptRuleSetMetadata.wrap(value))
    override val rules: Optional[List[zio.aws.ses.model.ReceiptRule.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rules())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ses.model.ReceiptRule.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
  ): zio.aws.ses.model.DescribeReceiptRuleSetResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ses_2.13-5.17.123.2-sources.jar: zio/aws/ses/model/DescribeReceiptRuleSetResponse.scala <==
package zio.aws.ses.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeReceiptRuleSetResponse(
    metadata: Option[zio.aws.ses.model.ReceiptRuleSetMetadata] = None,
    rules: Option[Iterable[zio.aws.ses.model.ReceiptRule]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse = {
    import DescribeReceiptRuleSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
      .builder()
      .optionallyWith(metadata.map(value => value.buildAwsValue()))(_.metadata)
      .optionallyWith(
        rules.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.rules)
      .build()
  }
  def asReadOnly: zio.aws.ses.model.DescribeReceiptRuleSetResponse.ReadOnly =
    zio.aws.ses.model.DescribeReceiptRuleSetResponse.wrap(buildAwsValue())
}
object DescribeReceiptRuleSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ses.model.DescribeReceiptRuleSetResponse =
      zio.aws.ses.model.DescribeReceiptRuleSetResponse(
        metadata.map(value => value.asEditable),
        rules.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def metadata: Option[zio.aws.ses.model.ReceiptRuleSetMetadata.ReadOnly]
    def rules: Option[List[zio.aws.ses.model.ReceiptRule.ReadOnly]]
    def getMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.ses.model.ReceiptRuleSetMetadata.ReadOnly
    ] = AwsError.unwrapOptionField("metadata", metadata)
    def getRules
        : ZIO[Any, AwsError, List[zio.aws.ses.model.ReceiptRule.ReadOnly]] =
      AwsError.unwrapOptionField("rules", rules)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
  ) extends zio.aws.ses.model.DescribeReceiptRuleSetResponse.ReadOnly {
    override val metadata
        : Option[zio.aws.ses.model.ReceiptRuleSetMetadata.ReadOnly] = scala
      .Option(impl.metadata())
      .map(value => zio.aws.ses.model.ReceiptRuleSetMetadata.wrap(value))
    override val rules: Option[List[zio.aws.ses.model.ReceiptRule.ReadOnly]] =
      scala
        .Option(impl.rules())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ses.model.ReceiptRule.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ses.model.DescribeReceiptRuleSetResponse
  ): zio.aws.ses.model.DescribeReceiptRuleSetResponse.ReadOnly = new Wrapper(
    impl
  )
}
